from setuptools import setup, find_packages

setup(
    name='antivirus-microservice',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'requests'
    ],
    include_package_data=True,
    description='A Python client for Antivirus Microservice',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/ivanoff/antivirus-microservice-python',
    author='Dimitry Ivanov',
    author_email='2@ivanoff.org.ua',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
